////////////////////////////////////////////////////////////////////////////
//   Copyright 2013  Teradici Corporation
//
//   This program is free software; you can redistribute it and/or modify it
//   under the terms and conditions of the GNU General Public License,
//   version 2, as published by the Free Software Foundation.
//
////////////////////////////////////////////////////////////////////////////
/// \file
/// \brief
///     Kernel Logging
///
///     This file defines the macros for kernel logging. The macros are
///     compiled in when compiling in a checked (DEBUG) environment, and left
///     out in a free (RELEASE) environment.
///
////////////////////////////////////////////////////////////////////////////

#pragma once

// ---- Include Files -------------------------------------------------------
#include "tera_dbg.h"

// ---- Constants and Types -------------------------------------------------

#define DBG
#undef DBG
#define INFO
//#undef INFO
#define ERR
//#undef ERR
#define CRIT
//#undef CRIT

// TBD - figure out how to enable KERN_DEBUG messages
//      printk(KERN_DEBUG "pcoip_host: [D] %s : " fmt "\n",
#ifdef DBG
#define mTERA_LOG_DBG(fmt, args...)                             \
do {                                                            \
        printk(KERN_INFO "pcoip_host: [D] %s : " fmt "\n",      \
               __func__, ##args);                               \
} while (0)
#else
#define mTERA_LOG_DBG(x, ...)
#endif  // DBG

#ifdef INFO
#define mTERA_LOG_INFO(fmt, args...)                            \
do {                                                            \
        printk(KERN_INFO "pcoip_host: [I] %s : " fmt "\n",      \
               __func__, ##args);                               \
} while (0)
#else
#define mTERA_LOG_INFO(x, ...)
#endif  // INFO

#ifdef ERR
#define mTERA_LOG_ERR(fmt, args...)                             \
do {                                                            \
        printk(KERN_ERR "pcoip_host: [E] %s : " fmt "\n",       \
               __func__, ##args);                               \
} while (0)
#else
#define mTERA_LOG_ERR(x, ...)
#endif  // ERR

#ifdef CRIT
#define mTERA_LOG_CRIT(fmt, args...)                            \
do {                                                            \
        printk(KERN_CRIT "pcoip_host: [C] %s : " fmt "\n",      \
               __func__, ##args);                               \
} while (0)
#else
#define mTERA_LOG_CRIT(x, ...)
#endif  // CRIT

#ifdef DBG
#define ASSERT(cond)                                            \
do {                                                            \
        if (!(cond)) {                                          \
        mTERA_LOG_CRIT("Assertion in file %s, function %s, line %d", \
                       __FILE__, __FUNCTION__, __LINE__);       \
        }                                                       \
} while (0)
#else
#define ASSERT(cond)
#endif  // DBG

// ---- Variable Externs ----------------------------------------------------

// ---- Function Prototypes -------------------------------------------------

